==> awkium-0.1.3-src.tar.gz: awkium/src/net/morilib/awk/io/PrintLineWriter.java <==
/*
 * Copyright 2013 Yuichiro Moriguchi
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.morilib.awk.io;

import java.io.IOException;
import java.io.PrintWriter;

/**
 * PrintWriterをラップするLineWriterです。
 *
 * @author MORIGUCHI, Yuichiro 2013/04/02
 */
public class PrintLineWriter implements LineWriter {

	private PrintWriter p;

	/**
	 * インスタンスを生成します。
	 * 
	 * @param p ラップされるPrintWriter
	 */
	public PrintLineWriter(PrintWriter p) {
		this.p = p;
	}

	/* (non-Javadoc)
	 * @see net.morilib.awk.io.LineWriter#print(java.lang.String)
	 */
	public void print(String s) {
		p.print(s);
	}

	/* (non-Javadoc)
	 * @see net.morilib.awk.io.LineWriter#println(java.lang.String)
	 */
	public void println(String s) {
		p.println(s);
	}

	/* (non-Javadoc)
	 * @see net.morilib.awk.io.LineWriter#printf(java.lang.String, java.lang.Object[])
	 */
	public void printf(String format, Object... args) {
		p.printf(format, args);
	}

	/* (non-Javadoc)
	 * @see net.morilib.awk.io.LineWriter#flush()
	 */
	public void flush() {
		p.flush();
	}

	/* (non-Javadoc)
	 * @see net.morilib.awk.io.LineWriter#close()
	 */
	public void close() throws IOException {
		p.close();
	}

}

==> awkium-0.2.3-src.tar.gz: awkium/src/net/morilib/awk/io/PrintLineWriter.java <==
/*
 * Copyright 2013 Yuichiro Moriguchi
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.morilib.awk.io;

import java.io.IOException;
import java.io.PrintWriter;

import net.morilib.awk.printf.Printf;

/**
 * PrintWriterをラップするLineWriterです。
 *
 * @author MORIGUCHI, Yuichiro 2013/04/02
 */
public class PrintLineWriter implements LineWriter {

	private PrintWriter p;

	/**
	 * インスタンスを生成します。
	 * 
	 * @param p ラップされるPrintWriter
	 */
	public PrintLineWriter(PrintWriter p) {
		this.p = p;
	}

	/* (non-Javadoc)
	 * @see net.morilib.awk.io.LineWriter#print(java.lang.String)
	 */
	public void print(String s) {
		p.print(s);
	}

	/* (non-Javadoc)
	 * @see net.morilib.awk.io.LineWriter#println(java.lang.String)
	 */
	public void println(String s) {
		p.println(s);
	}

	/* (non-Javadoc)
	 * @see net.morilib.awk.io.LineWriter#printf(java.lang.String, java.lang.Object[])
	 */
	public void printf(String format,
			Object... args) throws IOException {
//		p.printf(format, args);
		Printf.getInstance().format(p, format, args);
	}

	/* (non-Javadoc)
	 * @see net.morilib.awk.io.LineWriter#flush()
	 */
	public void flush() {
		p.flush();
	}

	/* (non-Javadoc)
	 * @see net.morilib.awk.io.LineWriter#close()
	 */
	public void close() throws IOException {
		p.close();
	}

}
